"use strict";
this.author    = "Zafrusteria";
this.copyright = "© 2024 Zafrusteria.";
this.license   = "Creative Commons: attribution, non-commercial,  CC BY-NC-SA 4.0 sharealike - see readme.txt";
this.version   = "0.8";
this.name = "ShrewsRights_comms_not_used";

// This file was taken from cim's oolite.oxp.cim.comms-pack-a.oxz with a few changes
// some of these functions are a copy/paste from deathcomms by phkb with some changes for ShrewsRights.

this.description = "Comms messages for antishrew extremists that attack shrews rights sympathisers and also specific deathcomms.";

// The generic prefix used for this OXP's comms entries in descriptions.plist
this.$commsPrefix = "ShrewsRights";
this.$includeRole = ["sr_extremist"]; // From shipdata.plist

this.$debug = false;

this.startUpComplete = function _ShrewsRightsAI_startUpComplete() {


    return;




    for (let i = 0 ; i < this.$includeRole.length; i++) {
        // Add "sr_extremist" to the list that Deathcomms ignores, this is from shipdata.plist.
        if (worldScripts.DeathComms) worldScripts.DeathComms._excludeRoles.push(this.$includeRole[i]);
    }

    /* See https://wiki.alioth.net/index.php/Oolite_Javascript_Reference:_PriorityAI_Documentation#Usage
     * for a list of Standard Communications Keys.
     * and for a usage example see cim's oolite.oxp.cim.comms-pack-a.oxz
     */

    // ensure the priority AI library is started
    if (worldScripts["oolite-libPriorityAI"].startUp) worldScripts["oolite-libPriorityAI"].startUp();

    /*  The comms structure below should result in an entry in worldScripts["oolite-libPriorityAI"].$commsSettings
        similar to the following:
            // 'role' from shipdata.plist
            sr_extremist: {
                // 'personality' for anti-shrew extremists, set in the AI script with ai.setCommunicationsPersonality
                ShrewsRights_extremist: {
                    oolite_surrender: "[ShrewsRights_extremist_surrender]",
                    oolite_beginningAttack: "[ShrewsRights_extremist_beginningAttack]",
                    oolite_attackLowEnergy: "[ShrewsRights_extremist_attackLowEnergy]"
                }
            }
    */
    let comms = {
        sr_extremist: { // Shipdata roles
            /* The _makeComms function saves a bit of typing on
             * defining key/value entries like
             * "oolite_attackLowEnergy": "[ShrewsRights_extremist_attackLowEnergy]",
             *
             *  Comms keys/values - see
             * http://wiki.alioth.net/index.php/Oolite_PriorityAI_Documentation#Usage
             * for a list of available keys.
             *
             * this._makeComms will generate keys for descriptions.plist such as:
             * ShrewsRights_extremist_surrender & ShrewsRights_extremist_attackLowEnergy
             *
             * They are made up from this.$commsPrefix and the two parameters passed into _makeComms.
             */

            // The name part can be anything we like but should include an OXP prefix. I just added that to the personality.
            // Personality for 'extremist' is set in the AI script
            ShrewsRights_extremist: this._makeComms("extremist",
                [
                    "attackLowEnergy",
                    "beginningAttack",
                    "makeDistressCall",
                    "surrender",
                    "thargoidAttack",
                ]),
        },
    };

    // This loads the communications settings into the library
    worldScripts["oolite-libPriorityAI"]._setCommunications(comms);
}

this.shipSpawned = function _ShrewsRights_shipSpawned(ship) {
    if (ship.primaryRole == this.$includeRole) {
         if (this.$debug)
             log(this.name, "ShipSpawned '" + ship.displayName + "' - '" + ship.shipUniqueName + "' - '" + ship.primaryRole + "'");
        // is there an existing script in shipDied?
        // move it to a new spot
        ship.script._dmShipDied = ship.script.shipDied;
        ship.script.shipDied = this._dmShipDied;
    }
}

this._dmShipDied = function _ShrewsRights__dmShipDied(whom, why) {
    if (this.$debug) log(this.name, "_dmShipDied '" + this.ship.displayName + "' - '" + this.ship.shipUniqueName + " " + why);
    if (this.ship.script._dmShipDied) this.ship.script._dmShipDied(whom, why);

    // Was way to chatty.
    if (why != "removed"  && Math.random() > 0.95) {
        if (this.ship.isDerelict == false) {
            if (this.$debug) log(this.name, "ShrewsRights_extremist_beginningAttack - sending comms");
            this.ship.commsMessage(expandDescription("[ShrewsRights_extremist_beginningAttack]"), player.ship);
        } else {
            if (this.$debug) log(this.name, "ShrewsRights_Derelict message - sending comms");
            this.ship.commsMessage(expandDescription("[ShrewsRights_extremist_derelictMessage]"), player.ship);
        }
    }
}

/* This function makes a set of descriptions.plist entries, to save a little
 * typing. this.$commsPrefix plus specific is the personality we're writing
 * for and 'entries' is an array of the communications keys that are
 * generated with "oolite_" appended to them.
 */
this._makeComms = function _ShrewsRightsAI_makeComms(specific, entries) {
    let result = {};
    let i = entries.length;
    while (i--) {
        let entry = entries[i];
        result["oolite_" + entry] = "[" + this.$commsPrefix + "_" + specific + "_" + entry + "]";
    }
    return result;
}
